==> keycloak-model-map-18.0.0-sources.jar: org/keycloak/models/map/client/MapProtocolMapperEntityFieldDelegate.java <==
package org.keycloak.models.map.client;
public class MapProtocolMapperEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.client.MapProtocolMapperEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.client.MapProtocolMapperEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.client.MapProtocolMapperEntity> entityFieldDelegate;
    public MapProtocolMapperEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.client.MapProtocolMapperEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.client.MapProtocolMapperEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.client.MapProtocolMapperEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.client.MapProtocolMapperEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.client.MapProtocolMapperEntityFields.NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.client.MapProtocolMapperEntityFields.NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getProtocolMapper() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.client.MapProtocolMapperEntityFields.PROTOCOL_MAPPER);
    }
    @SuppressWarnings("unchecked") @Override public void setProtocolMapper(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.client.MapProtocolMapperEntityFields.PROTOCOL_MAPPER, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getConfig() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.client.MapProtocolMapperEntityFields.CONFIG);
    }
    @SuppressWarnings("unchecked") @Override public void setConfig(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.client.MapProtocolMapperEntityFields.CONFIG, p0);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/client/MapProtocolMapperEntityFieldDelegate.java <==
package org.keycloak.models.map.client;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapProtocolMapperEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.client.MapProtocolMapperEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.client.MapProtocolMapperEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.client.MapProtocolMapperEntity> entityFieldDelegate;
    public MapProtocolMapperEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.client.MapProtocolMapperEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.client.MapProtocolMapperEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.client.MapProtocolMapperEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.client.MapProtocolMapperEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.client.MapProtocolMapperEntityFields.NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.client.MapProtocolMapperEntityFields.NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getProtocolMapper() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.client.MapProtocolMapperEntityFields.PROTOCOL_MAPPER);
    }
    @SuppressWarnings("unchecked") @Override public void setProtocolMapper(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.client.MapProtocolMapperEntityFields.PROTOCOL_MAPPER, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getConfig() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.client.MapProtocolMapperEntityFields.CONFIG);
    }
    @SuppressWarnings("unchecked") @Override public void setConfig(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.client.MapProtocolMapperEntityFields.CONFIG, p0);
    }
}
